@@ -1,9 +1,8 @@
-_name_map_ = {
-"pprint_formatter": "pprint"
-}
+_name_map_ = {"pprint_formatter": "pprint"}
+
 
 def pprint_formatter(data, **kwargs):
-    """Method to pprint format results
-    """
+    """Method to pprint format results"""
     from pprint import pformat
-    return pformat(data, indent=4)
\ No newline at end of file
+
+    return pformat(data, indent=4)
